@@ -31,9 +31,13 @@ PYBIND11_MODULE(_osm, m) {
         .def_property_readonly("y", &osmium::Location::y,
              "(read-only) Y coordinate (latitude) as a fixed-point integer.")
         .def_property_readonly("lon", &osmium::Location::lon,
-             "(read-only) Longitude (x coordinate) as floating point number.")
+             "(read-only) Longitude (x coordinate) as floating point number."
+             "Raises an :py:class:`osmium.InvalidLocationError` when the "
+             "location is invalid.")
         .def_property_readonly("lat", &osmium::Location::lat,
-             "(read-only) Latitude (y coordinate) as floating point number.")
+             "(read-only) Latitude (y coordinate) as floating point number."
+             "Raises an :py:class:`osmium.InvalidLocationError` when the "
+             "location is invalid.")
         .def("valid", &osmium::Location::valid,
              "Check that the location is a valid WGS84 coordinate, i.e. "
              "that it is within the usual bounds.")
@@ -191,7 +195,10 @@ PYBIND11_MODULE(_osm, m) {
              "True if the start and end node are exactly the same.")
         .def("ends_have_same_location", &osmium::NodeRefList::ends_have_same_location,
              "True if the start and end node of the way are at the same location. "
-             "Throws an exception if the location of one of the nodes is missing.")
+             "Expects that the coordinates of the way nodes have been loaded "
+             "(see :py:func:`osmium.SimpleHandler.apply_buffer` and "
+             ":py:func:`osmium.SimpleHandler.apply_file`). "
+             "If the locations are not present then the function returns always true.")
     ;
 
     py::class_<osmium::WayNodeList, osmium::NodeRefList>(m, "WayNodeList",
@@ -280,7 +287,10 @@ PYBIND11_MODULE(_osm, m) {
              "True if the start and end node are exactly the same.")
         .def("ends_have_same_location", &osmium::Way::ends_have_same_location,
              "True if the start and end node of the way are at the same location."
-             "Throws an exception if the location of one of the nodes is missing.")
+             "Expects that the coordinates of the way nodes have been loaded "
+             "(see :py:func:`osmium.SimpleHandler.apply_buffer` and "
+             ":py:func:`osmium.SimpleHandler.apply_file`). "
+             "If the locations are not present then the function returns always true.")
     ;
 
     py::class_<osmium::Relation, osmium::OSMObject>(m, "Relation",
